module.exports = {
    name: "Get Property From Object",

    description: "Gets the property from the object.",

    category: "Object Stuff",

    inputs: [
        {
            id: "action",
            name: "Action",
            description: "Acceptable Types: Action\n\nDescription: Executes this block.",
            types: ["action"]
        },
        {
            id: "object",
            name: "Object",
            description: "Acceptable Types: Object, Unspecified\n\nDescription: The object to get the property.",
            types: ["object", "unspecified"],
            required: true
        },
        {
            id: "key",
            name: "Key",
            description: "Acceptable Types: Text, Unspecified\n\nDescription: The key of the property to get.",
            types: ["text", "unspecified"],
            multiInput: true
        }
    ],

    options: [],

    outputs: [
        {
            id: "action",
            name: "Action",
            description: "Type: Action\n\nDescription: Executes the following blocks when this block finishes its task.",
            types: ["action"]
        },
        {
            id: "values",
            name: "Value",
            description: "Type: Object\n\nDescription: The property value obtained.",
            types: ["unspecified"],
            multiOutput: true
        }
    ],

    code(cache) {
        const object = this.GetInputValue("object", cache);
        var keys = this.GetInputValue("key", cache);
        var values = [];

        function findNestedValue(obj, key) {
            if (obj.hasOwnProperty(key)) {
                return obj[key];
            }
            for (var prop in obj) {
                if (typeof obj[prop] === 'object') {
                    var result = findNestedValue(obj[prop], key);
                    if (result !== undefined) {
                        return result;
                    }
                }
            }
            return undefined;
        }

        for (const [index, value] of keys.entries()) {
            let result = object;
            let search = value;

            if (value.includes(';')) {
                search = value.split(';');
                for (let i = 0; i < search.length; i++) {
                    result = result[search[i]];
                }
                values.push(result);
            } else {
                result = findNestedValue(object, value);
                values.push(result);
            }
        };                              

        this.StoreOutputValue(values, "values", cache);
        this.RunNextBlock("action", cache);
        
    }
}